@@ -542,6 +542,7 @@ class CameraGroup:
             subp = points[:, ip, :]
             good = ~np.isnan(subp[:, 0])
             if np.sum(good) >= 2:
+
                 out[ip] = triangulate_simple(subp[good], cam_mats[good])
 
         if one_point:
@@ -1656,6 +1657,9 @@ class CameraGroup:
         verbose=True,
         **kwargs
     ):
+
+        all_rowsOG = all_rows.copy()
+
         """Assumes camera sizes are set properly"""
         for rows, camera in zip(all_rows, self.cameras):
             size = camera.get_size()
@@ -1679,20 +1683,23 @@ class CameraGroup:
         for i, (row, cam) in enumerate(zip(all_rows, self.cameras)):
             all_rows[i] = board.estimate_pose_rows(cam, row)
 
+        charuco_frames = [f['framenum'][1] for f in all_rows[0]]
+
         merged = merge_rows(all_rows)
         imgp, extra = extract_points(merged, board, min_cameras=2)
 
         if init_extrinsics:
             rtvecs = extract_rtvecs(merged)
             if verbose:
-                pprint(get_connections(rtvecs, self.get_names()))
-            rvecs, tvecs = get_initial_extrinsics(rtvecs)
-            self.set_rotations(rvecs)
-            self.set_translations(tvecs)
+                pprint(get_connections(rtvecs, self.get_names()))   
+                rvecs, tvecs = get_initial_extrinsics(rtvecs)
+                self.set_rotations(rvecs)
+                self.set_translations(tvecs)
+
 
         error = self.bundle_adjust_iter(imgp, extra, verbose=verbose, **kwargs)
 
-        return error, merged
+        return error, merged, charuco_frames
 
     def get_rows_videos(self, videos, board, verbose=True):
         all_rows = []
@@ -1734,7 +1741,7 @@ class CameraGroup:
         if init_extrinsics:
             self.set_camera_sizes_videos(videos)
 
-        error, merged = self.calibrate_rows(
+        error, merged, charuco_frames = self.calibrate_rows(
             all_rows,
             board,
             init_intrinsics=init_intrinsics,
@@ -1742,7 +1749,7 @@ class CameraGroup:
             verbose=verbose,
             **kwargs
         )
-        return error, merged
+        return error, merged, charuco_frames
 
     def get_dicts(self):
         out = []
